# ################################################################################
# Title: HATI monitor
# Project: HATI
#
# File       : monitor.tcl
#
# Description: 
#    It reads all the parameters read in the monitor lite
#    and print them all.
# 
# Parameters: None.
#
# Return: None
#
# Licence and Copyright:
# Copyright (c) 2022 Safran Trusted 4D (https://www.safran-group.com/companies/safran-trusted-4d)
#
# You might use, distribute and modify this code and its resulting
# binary form under the terms of the LICENSE.txt provided within the
# repository or project.
#
# If you have not received a copy of the LICENSE.txt along with
# this file please write to info<DOT>spain<AT>orolia<DOT>com and consider that
# this file can not be copied and/or distributed in any forms.
# ################################################################################

proc monitor_lite {} {
    source ./tcl_libs/memmap.tcl; list

    set mode         [eval read_mode]
    set mac          [eval read_mac]
    set uptime       [eval read_uptime]
    set sfp_plugged  [eval read_sfp_plugged] 
    set tai          [eval read_tai]
    set link_status  [eval read_link_status]
    set packets      [eval read_packets]
    set servo        [eval read_servo_state_name]
    set track_phase  [eval read_track_phase]
    set rtt          [eval read_rtt]
    set ms_delay     [eval read_ms_delay]
    set delay_m      [eval read_master_delay]
    set delay_s      [eval read_slave_delay]
    set semistatic   [eval read_semistatic_rx]
    set clk_offset   [eval read_clock_offset]
    set manual_shift [eval read_manual_shift]

    puts "======== MONITOR LITE ========"


    # Prints the HATI mode
    puts "HATI Mode:            ${mode}"

    # Prints the Local MAC Address
    puts "Local MAC Address:    ${mac}"

    # Prints the HATI uptime
    puts "HATI uptime:          ${uptime}"

    # Prints SFP Info if is sfp_plugged
    puts "${sfp_plugged}"
    
    # Prints the TAI Sec (dont format it)
    puts "HATI TAI:             ${tai}"

    # Prints the Link status
    puts "Link status:          ${link_status}"

    # Prints the rx and tx packets
    puts "Packets:              ${packets}"

    # Prints the servo state
    puts "Servo state name:     ${servo}"

    # Prints the Track Phase
    puts "Track Phase:          ${track_phase}"

    # Prints the RTT
    puts "RTT:                  ${rtt}"

    # Prints the MS Delay 
    puts "MS Delay:             ${ms_delay}"

    # Prints the Master and Slave delays
    puts "Master:               ${delay_m}"
    puts "Slave:                ${delay_s}"

    # Prints the Semistatic Rx Value
    puts "Semistatic RX Value:  ${semistatic}"

    # Prints the offset
    puts "Clock offset:         ${clk_offset}"

    # Prints the manual shift
    puts "Manual shift (ps):    ${manual_shift}"

    puts "\n"
}

# ###############################################################
# Name: monitor_expert.
#
# Description: 
#    It reads all the parameters read in the monitor expert
#    and print them all.
# 
# Parameters: None.
#
# Return: None
# ###############################################################
proc monitor_expert {} {
    source ./tcl_libs/memmap.tcl; list

    set mode         [eval read_mode]
    set mac          [eval read_mac]
    set uptime       [eval read_uptime]
    set sfp_plugged  [eval read_sfp_plugged] 
    set dac_value    [eval read_dac_value]
    set tai          [eval read_tai]
    set link_status  [eval read_link_status]
    set packets      [eval read_packets]
    set servo        [eval read_servo]
    set clk_offset   [eval read_clock_offset]
    set manual_shift [eval read_manual_shift]
    
    set core_build          [eval read_hati_core_build]
    set build               [eval read_build]
    set locked              [eval read_locked]
    set calibrated          [eval read_calibrated]
    set track_phase         [eval read_track_phase]
    set servo_state_name    [eval read_servo_state_name]
    set rtt                 [eval read_rtt]
    set ms_delay            [eval read_ms_delay]
    set delay_m             [eval read_master_delay]
    set delay_s             [eval read_slave_delay]
    set semistatic          [eval read_semistatic_rx]
    set t24p_delay          [eval read_t24p_delay]
    set link_assymetry      [eval read_link_asymmetry]
    set cable_rtt           [eval read_cable_rtt]
    set current_offset      [eval read_current_offset]
    set m_clk_class         [eval read_master_clock_class]
    set skew                [eval read_skew]
    set update_count        [eval read_update_count]
    # set temp                [eval read_temperature]
    set eeprom_detected     [eval read_eeprom_detected]

    set utc_offset_valid    [eval read_utc_offset_valid]
    set utc_offset          [eval read_utc_offset]
    set clock_id            [eval read_clock_id]
    set step_removed        [eval read_step_removed]

    puts "======== MONITOR EXPERT ========"

    # Prints the HATI Core build information
    puts "HATI Core build:      ${core_build}"

    # Prints the Build information (repository)
    puts "Build:                ${build}"

    # Prints the HATI mode
    puts "HATI Mode:            ${mode}"

    # Prints the Local MAC Address
    puts "Local MAC Address:    ${mac}"

    # Prints the HATI uptime
    puts "HATI uptime:          ${uptime}"

    # Prints SFP Info if is sfp_plugged
    puts "${sfp_plugged}"

    # Prints DAC value
    puts "DAC value:            ${dac_value}"
    
    # Prints the TAI Sec (dont format it)
    puts "HATI TAI:             ${tai}"

    # Prints the Link status
    puts "Link status:          ${link_status}"

    # Prints the rx and tx packets
    puts "Packets:              ${packets}"

    # Prints locked state
    puts "Locked:               ${locked}"

    # Prints if it's calibrated
    puts "Calibrated:           ${calibrated}"

    # Prints the Track Phase
    puts "Track Phase:          ${track_phase}"

    # Prints the servo state name
    puts "Servo state name:     ${servo_state_name}"

    # Prints the servo state
    puts "Servo state:          ${servo}"

    # Prints the RTT
    puts "RTT:                  ${rtt}"

    # Prints the MS Delay 
    puts "MS Delay:             ${ms_delay}"

    # Prints the Master and Slave delays
    puts "Master:               ${delay_m}"
    puts "Slave:                ${delay_s}"

    # Prints the Semistatic Rx Value
    puts "Semistatic RX Value:  ${semistatic}"

    # Prints the t24p
    puts "t24p delay:           ${t24p_delay}"

    # Prints the link asymmetry
    puts "link asymmetry:       ${link_assymetry}"

    # Prints the cable RTT
    puts "cable RTT:            ${cable_rtt}"

    # Prints the offset
    puts "Clock offset:         ${clk_offset}"

    # Prints the current offset
    puts "Current setpoint:     ${current_offset}"

    # Prints the Master Clock Class
    puts "Master Clock Class:   ${m_clk_class}"

    # Prints the skew value
    puts "Skew:                 ${skew}"

    # Prints the Update count
    puts "Update count:         ${update_count}"

    # # Prints the temperature value
    # puts "Temperature:          ${temp} ºC"

    # Prints if EEPROM is detected
    puts "EEPROM detected:      ${eeprom_detected}"

    # Prints the manual shift
    puts "Manual shift (ps):    ${manual_shift}"

    puts "\n"

    # Prints the current UTC offset valid:
    puts "HATI current UTC offset valid:      ${utc_offset_valid}"

    # Prints the current UTC offset:
    puts "HATI current UTC offset:            ${utc_offset}"

    # Prints the clock ID
    puts "Clock ID:                           ${clock_id}"

    # Prints the HATI clock ID
    puts "HATI stepts removed:                ${step_removed}"

    puts "\n"

}

proc monitor_getlink {} {

    source ./tcl_libs/memmap.tcl; list

    set link_status  [eval read_link_status]

    set outfile [open "./temp0.txt" w+]  
    puts $outfile $link_status

    puts "${link_status}"

}

proc monitor_gettf {} {

    source ./tcl_libs/memmap.tcl; list

    set track_phase         [eval read_track_phase]

    set outfile [open "./temp0.txt" w+]  
    puts $outfile $track_phase

}
